<?php
/**
 * viewtube functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package viewtube
 */


if ( ! function_exists( 'viewtube_setup' ) ) :

	function viewtube_setup() {

		load_theme_textdomain( 'viewtube', get_template_directory() . '/languages' );
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'title-tag' );
		add_theme_support( 'post-thumbnails' );
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'viewtube' )
		) );
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );
		add_theme_support( 'custom-background', apply_filters( 'viewtube_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );
		add_theme_support( 'customize-selective-refresh-widgets' );
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
		add_image_size( 'viewtube-1280x720', 1280,720,true );
		add_image_size( 'viewtube-32x32', 32,32,true );
		add_image_size( 'viewtube-200x160', 200,160,true );
		add_image_size( 'viewtube-210x120', 210,120,true );

	}

endif;
add_action( 'after_setup_theme', 'viewtube_setup' );

function viewtube_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'viewtube_content_width', 640 );
}
add_action( 'after_setup_theme', 'viewtube_content_width', 0 );

function viewtube_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'viewtube' ),
		'id'            => 'sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'viewtube' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	));
	
	register_sidebar( array(
		'name'          => esc_html__( 'Video Sidebar', 'viewtube' ),
		'id'            => 'video-sidebar',
		'description'   => esc_html__( 'Add widgets here.', 'viewtube' ),
		'before_widget' => '<div id="%1$s" class="widget widget-video %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	));
}
add_action( 'widgets_init', 'viewtube_widgets_init' );


// Register Fonts
function viewtube_fonts_url() {
	$fonts_url = '';
	$fonts     = array();
	$subsets   = 'latin,latin-ext';

	/*
	 * translators: If there are characters in your language that are not supported
	 * by Rubik, translate this to 'off'. Do not translate into your own language.
	 */
	if ( 'off' !== _x( 'on', 'Fira Sans Condensed font: on or off', 'viewtube' ) ) {
		$fonts[] = 'Fira Sans Condensed:100,200,300,400,500,600,700,800,900';
	}

	/*
	 * translators: If there are characters in your language that are not supported
	 * by Oswald, translate this to 'off'. Do not translate into your own language.
	 */
	if ( 'off' !== _x( 'on', 'Open Sans font: on or off', 'viewtube' ) ) {
		$fonts[] = 'Open Sans:300,400,600,700,800';
	}

	if ( $fonts ) {
		$fonts_url = add_query_arg(
			array(
				'family'  => urlencode( implode( '|', $fonts ) ),
				'subset'  => urlencode( $subsets ),
				'display' => urlencode( 'fallback' ),
			),
			'https://fonts.googleapis.com/css'
		);
	}

	return $fonts_url;
}

// Scripts
function viewtube_scripts() {
	// CSS
	wp_enqueue_style( 'viewtube-fonts', viewtube_fonts_url());
	wp_enqueue_style( 'animate', get_template_directory_uri() . '/assets/css/animate.min.css');
	wp_enqueue_style( 'viewtube-default', get_template_directory_uri() . '/assets/css/default.css');
	wp_enqueue_style( 'fontawesome', get_template_directory_uri() . '/assets/css/fontawesome.min.css');
	wp_enqueue_style( 'magnific-popup', get_template_directory_uri() . '/assets/css/magnific-popup.min.css');
	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.min.css');
	wp_enqueue_style( 'plyr', get_template_directory_uri() . '/assets/css/plyr.css');
	wp_enqueue_style( 'select2', get_template_directory_uri() . '/assets/css/select2.min.css');
	wp_enqueue_style( 'viewtube-style', get_stylesheet_uri() );
	wp_enqueue_style( 'viewtube-dark', get_stylesheet_uri());


	global $viewtube_opt;

	$dark_mood = !empty( $viewtube_opt['dark_mood'] ) ? $viewtube_opt['dark_mood'] : '';
 	

	//HTTP GET
	if(!empty($_GET['mood'])){
	    $dark_mood = $_GET['mood'];
	}
	// http://localhost/viewtube/?mood=true


	if($dark_mood){
		$default_mood = 'dark';	
	} else {
		$default_mood = '';
	}


	// JS
	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.min.js', array('jquery'), wp_get_theme()->get( 'Version' ), true );
	wp_enqueue_script( 'plyr', get_template_directory_uri() . '/assets/js/plyr.js', array(), wp_get_theme()->get( 'Version' ), true );
	wp_enqueue_script( 'magnific-popup', get_template_directory_uri() . '/assets/js/jquery.magnific-popup.min.js', array('jquery'), wp_get_theme()->get( 'Version' ), true );
	wp_enqueue_script( 'select2', get_template_directory_uri() . '/assets/js/select2.min.js', array('jquery'), wp_get_theme()->get( 'Version' ), true );
	wp_enqueue_script( 'slick', get_template_directory_uri() . '/assets/js/slick.min.js', array('jquery'), wp_get_theme()->get( 'Version' ), true );
	wp_enqueue_script( 'lazyload', get_template_directory_uri() . '/assets/js/lazyload.js', array('jquery'), wp_get_theme()->get( 'Version' ), true );
	wp_enqueue_script( 'cookie', get_template_directory_uri() . '/assets/js/jquery.cookie.min.js', array('jquery'), wp_get_theme()->get( 'Version' ), true );
  	wp_enqueue_script( 'viewtube-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(), wp_get_theme()->get( 'Version' ), true );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	wp_enqueue_script( 'viewtube-main', get_template_directory_uri() . '/assets/js/main.js', array('jquery','slick','magnific-popup','plyr','cookie','lazyload'), wp_get_theme()->get( 'Version' ), true );

	wp_localize_script( 'viewtube-main', 'viewtubeAjaxUrlObj', array( 
		'ajaxurl' => admin_url( 'admin-ajax.php' ), 
		'default_mood' => $default_mood, 
		'dark_url' => get_template_directory_uri() . '/assets/css/dark.css', 
		'logo_url' => wp_get_attachment_url( get_theme_mod( 'custom_logo' ) ), 
		'dark_logo_url' => !empty($viewtube_opt['dark_mood_logo']['url']) ? $viewtube_opt['dark_mood_logo']['url'] : '',
	));
  
	//'viewtube-style' is main style of the theme
  	wp_add_inline_style( 'viewtube-style', viewtube_inline_style());
}

add_action( 'wp_enqueue_scripts', 'viewtube_scripts' );

// Denqueue scripts and styles.
function viewtube_dequeue_script() {
    wp_dequeue_style( 'elementor-animations' );
    wp_deregister_style( 'elementor-animations' );
}
add_action( 'wp_enqueue_scripts', 'viewtube_dequeue_script', 20 );

// Includes files
require get_template_directory() . '/inc/inline-script.php';
if (empty(get_user_meta( get_current_user_id(), 'licence_activated' , true ))) {
	require get_template_directory() . '/inc/activate-license.php';
}
require get_template_directory() . '/inc/redux-framework.php';
require get_template_directory() . '/inc/class-tgm-plugin-activation.php';
require get_template_directory() . '/inc/customizer.php';
require get_template_directory() . '/inc/breadcrumb.php';
require get_template_directory() . '/inc/ajax.php';
require get_template_directory() . '/inc/cmb.php';

// TGM required plugins
function viewtube_register_required_plugins() {

	$plugins = array(

		array(
			'name'        => esc_html__('Redux Framework', 'viewtube'),
			'slug'        => 'redux-framework',
			'required' 	  => true,
		),

		array(
			'name'        =>  esc_html__('Elementor', 'viewtube'),
			'slug'        => 'elementor',
			'
			required'    => true,
		),

		array(
			'name'        =>  esc_html__('CMB2', 'viewtube'),
			'slug'        => 'cmb2',
			'
			required'    => true,
		),

		array(
			'name'        => esc_html__('ViewTube Element', 'viewtube'),
			'slug'        => 'viewtube-element',
			'source'      => 'https://themebing.com/wp-json/download/purchase_code='.get_user_meta( get_current_user_id(), 'licence_activated' , true ).'/name=viewtube-element',
			'required' 	  => true,
		),
		
		array(
			'name'        => esc_html__('One Click Demo Import', 'viewtube'),
			'slug'        => 'one-click-demo-import',
			'required' 	  => true,
		)
	);

	$config = array(
		'id'           => 'viewtube',
		'default_path' => '',
		'menu'         => 'tgmpa-install-plugins',
		'has_notices'  => true,
		'dismissable'  => true,
		'dismiss_msg'  => '', 
		'is_automatic' => false,
		'message'      => '',  
	);

	tgmpa( $plugins, $config );
}

add_action( 'tgmpa_register', 'viewtube_register_required_plugins' );

// One click demo import
function viewtube_import_files() {
	return array(
		array(
			'import_file_name'             => __( 'Default', 'viewtube' ),
			'local_import_file'            => trailingslashit( get_template_directory() ) . 'inc/demo/default/content.xml',
			'local_import_widget_file'     => trailingslashit( get_template_directory() ) . 'inc/demo/default/widgets.wie',
			'local_import_customizer_file' => trailingslashit( get_template_directory() ) . 'inc/demo/default/customizer.dat',
			'local_import_redux'           => array(
				array(
					'file_path'   => trailingslashit( get_template_directory() ) . 'inc/demo/redux.json',
					'option_name' => 'viewtube_opt',
				),
			),
			'import_notice'                => __( 'Redux option name is “viewtube_opt”', 'viewtube' ),
			'preview_url'                  => 'https://themebing.com/wp/viewtube/',
		)
	);
}

if (!empty(get_user_meta( get_current_user_id(), 'licence_activated' , true ))) {			
	add_filter( 'pt-ocdi/import_files', 'viewtube_import_files' );
}

// Default Home and Blog Setup
function viewtube_after_import_setup() {
    // Assign menus to their locations.
    $main_menu = get_term_by( 'name', 'Menu', 'nav_menu' );

    set_theme_mod( 'nav_menu_locations', array(
            'primary' => $main_menu->term_id,
        )
    );

    // Assign front page and posts page (blog page).
    $front_page_id = get_page_by_title( 'Home' );
    $blog_page_id  = get_page_by_title( 'Blog' );

    update_option( 'show_on_front', 'page' );
    update_option( 'page_on_front', $front_page_id->ID );
    update_option( 'page_for_posts', $blog_page_id->ID );
}
add_action( 'pt-ocdi/after_import', 'viewtube_after_import_setup' );

// Related Posts
function viewtube_related_posts(){

    global $viewtube_opt;

    if (!empty($viewtube_opt['related_posts']) && $viewtube_opt['related_posts']!='') {
         $posts_per_page = !empty( $viewtube_opt['posts_per_page'] ) ? $viewtube_opt['posts_per_page'] : '';
         $related_posts_columns = !empty( $viewtube_opt['related_posts_columns'] ) ? $viewtube_opt['related_posts_columns'] : '';
         $related_post_title = !empty( $viewtube_opt['related_post_title'] ) ? $viewtube_opt['related_post_title'] : '';
        
        global $post;

        $related = get_posts( array( 
            'category__in' => wp_get_post_categories($post->ID),
            'posts_per_page' => $posts_per_page,
            'post_type' => 'post', 
            'post__not_in' => array($post->ID) 
        ) ); ?>

      <?php if ($related): ?>
        <div class="related-posts">
          <h4><?php echo esc_html( $related_post_title ) ?></h4>
          <div class="row">
              <?php
                  if( $related ) foreach( $related as $post ) { 
                  setup_postdata($post); ?>
                  <div class="col-md-12 col-xl-<?php echo esc_attr( $related_posts_columns ) ?>">
                	<div class="blog-item">
	                  <?php if (has_post_thumbnail()): ?>
	                  <div class="blog-thumb">
	                     <a href="<?php the_permalink() ?>">
	                        <?php the_post_thumbnail( 'viewtube-600x399' ) ?>
	                     </a>
	                  </div>
	                  <?php endif ?> 
	                  <div class="blog-content">
	                     <div class="blog-meta">
	                        <a href="<?php echo get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ); ?>">
	                        <img src="<?php echo esc_url( get_avatar_url( get_the_author_meta( 'ID' ) ) ); ?>" alt="<?php the_author(); ?>"></a>
	                        <span class="pr-10"> - <?php the_author(); ?></span>
	                        |
	                        <span class="pl-10">
	                           <?php $categories = get_the_category();
	                           if ( ! empty( $categories ) ) {
	                               echo '<a href="' . esc_url( get_category_link( $categories[0]->term_id ) ) . '">' . esc_html( $categories[0]->name ) . '</a>';
	                           }?>
	                        </span>
	                     </div>
	                     <h4><a href="<?php the_permalink() ?>"><?php echo mb_strimwidth( get_the_title(), 0, 70, '..' );?></a></h4>
	                  </div>
	               </div>
                  </div>
              <?php } wp_reset_postdata(); ?> 
          </div>
      </div><!-- .related-posts --> 

      <?php endif ?>
    <?php } 
}

// Video player
function video_player($class){

	global $viewtube_opt;
	$payment_membership_page = !empty( $viewtube_opt['payment_membership_page'] ) ? $viewtube_opt['payment_membership_page'] : '#';
	$video_display_as = get_post_meta( get_the_ID(), 'video_display_as', 1 );
	$video_file = get_post_meta( get_the_ID(), 'video_file', 1 );
	$video_caption_file = get_post_meta( get_the_ID(), 'video_caption_file', 1 );
	$youtube_video_url = get_post_meta( get_the_ID(), 'youtube_video_url', 1 );
	$vimeo_video_url = get_post_meta( get_the_ID(), 'vimeo_video_url', 1 );
	if (is_plugin_active( 'viewtube-subscription/viewtube-subscription.php' )) {
		if (get_post_meta(get_the_ID(),'membership', 1)) {
			$membership = json_decode(get_post_meta(get_the_ID())['membership'][0],true);
		}		   
	}

	$poster = get_the_post_thumbnail_url(get_the_ID(), 'full');
			
	if ( empty($membership) || viewtube_get_membership_validation(get_current_user_id()) == true) {
		if ($video_display_as == 'default') { ?>
		 	<video class="<?php echo esc_attr($class) ?>" preload="none" playsinline controls data-poster="<?php echo get_the_post_thumbnail_url(get_the_ID(), 'full') ?>">
			  <source src="<?php echo esc_url( $video_file ) ?>" type="video/mp4" />
			  <source src="<?php echo esc_url( $video_file ) ?>" type="video/webm" />
			  <!-- Captions are optional -->
			  <track kind="captions" label="English captions" src="<?php echo esc_url( $video_caption_file ) ?>" srclang="en" default />
			</video>
		<?php } elseif ($video_display_as == 'youtube') { ?>
			<div class="plyr__video-embed <?php echo esc_attr($class) ?>">
			    <iframe
			        src="<?php echo esc_url( $youtube_video_url ) ?>?origin=iv_load_policy=3&amp;modestbranding=1&amp;playsinline=1&amp;showinfo=0&amp;rel=0&amp;enablejsapi=1"
			        allowfullscreen
			        allowtransparency
			        allow="autoplay" width="100%" height="100%"
			        loading="lazy"
			    ></iframe>
			</div>
		<?php } elseif ($video_display_as == 'vimeo') { ?>
			<div class="plyr__video-embed <?php echo esc_attr($class) ?>">
			    <iframe
			        src="<?php echo esc_url( $vimeo_video_url ) ?>?loop=false&amp;byline=false&amp;portrait=false&amp;title=false&amp;speed=true&amp;transparent=0&amp;gesture=media"
			        allowfullscreen
			        allowtransparency
			        allow="autoplay"
			        loading="lazy"
			    ></iframe>
			</div>
		<?php }
	} else { ?>
		<div class="video-restricted <?php echo esc_attr($class) ?>">
			<div class="overlay-content">
				<div>
					<h4><?php echo esc_html__('Premium content','viewtube'); ?></h4>
					<i class="fas fa-lock"></i>
					<a href="<?php echo esc_url(get_the_permalink($payment_membership_page)); ?>"><?php echo esc_html__('Unlock', 'viewtube') ?></a>
				</div>
			</div>
			<?php if ($poster){ ?>
				<img src="<?php echo get_the_post_thumbnail_url(get_the_ID(), 'full') ?>" alt="<?php the_title_attribute(); ?>">
			<?php }else{?>
				<img src="<?php echo esc_url(get_template_directory_uri().'/assets/images/placeholder.png') ?>" alt="<?php the_title_attribute(); ?>">
			<?php } ?>
		</div>
	<?php
	}
}
add_action( 'video_player', 'video_player', 10 );

// Video URL
function get_video_url(){
	$video_display_as = get_post_meta( get_the_ID(), 'video_display_as', 1 );
	$video_file = get_post_meta( get_the_ID(), 'video_file', 1 );
	$youtube_video_url = get_post_meta( get_the_ID(), 'youtube_video_url', 1 );
	$vimeo_video_url = get_post_meta( get_the_ID(), 'vimeo_video_url', 1 );

	if ($video_display_as == 'default') { ?>
	 	<?php return $video_file; ?>
	<?php } elseif ($video_display_as == 'youtube') { ?>
		<?php return $youtube_video_url; ?>
	<?php  } elseif ($video_display_as == 'vimeo') { ?>
		<?php return $vimeo_video_url; ?>
	<?php }
}

// Comment List
function viewtube_comment_list($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment;
	extract($args, EXTR_SKIP);

	if ( 'article' == $args['style'] ) {
		$tag = 'article';
		$add_below = 'comment';
	} else {
		$tag = 'li';
		$add_below = 'comment';
	}
?>

<<?php echo esc_html( $tag ) ?> <?php comment_class(empty( $args['has_children'] ) ? '' :'parent') ?> id="comment-<?php comment_ID() ?>" itemscope itemtype="http://schema.org/Comment">
	<div class="row">
		<?php
		$avatar = get_avatar( $comment, 90 );
		if ($avatar): ?>
			<div class="col-md-2 col-xs-3 text-left text-md-center">
		        <?php echo get_avatar( $comment, 90 ); ?>
		    </div>
		<?php endif ?>	    
	    <div class="<?php if( $avatar =='' ){ echo 'col-md-12'; } else { echo'col-md-10 col-xs-9'; } ?>">
	        <div class="commenter">
	            <?php echo get_comment_author_link(); ?>
	            <span><?php comment_date('jS F Y , ').comment_time() ?></span>
	        </div>
	        <?php comment_text() ?>
	        <?php comment_reply_link(array_merge( $args, array('add_below' => $add_below, 'depth' => $depth, 'max_depth' => $args['max_depth']))) ?>	        
	        <?php if ($comment->comment_approved == '0') : ?>
			<p class="comment-meta-item"><?php echo esc_html__( 'Your comment is awaiting moderation.', 'viewtube' ) ?></p>
			<?php endif; ?>
			<?php edit_comment_link('<p class="comment-meta-item">Edit this comment</p>','',''); ?>
	    </div>
	</div>
<?php }


//Comment Field to Bottom
function viewtube_comment_field_to_bottom( $fields ) {
    $comment_field = $fields['comment'];
    unset( $fields['comment'] );
    $fields['comment'] = $comment_field;
    return $fields;
}
add_filter( 'comment_form_fields', 'viewtube_comment_field_to_bottom' );

// Archive count on rightside
function viewtube_archive_count_on_rightside($links) {
    $links = str_replace('</a>&nbsp;(', '</a> <span class="float-right">(', $links);
    $links = str_replace(')', ')</span>', $links);
    return $links;
}

add_filter( 'get_archives_link', 'viewtube_archive_count_on_rightside' );

// Category count on rightside
function viewtube_category_count_on_rightside($links) {
    $links = str_replace('</a>&nbsp;(', '</a> <span class="float-right">(', $links);
    $links = str_replace(')', ')</span>', $links);
    return $links;
}

add_filter( 'category_link', 'viewtube_category_count_on_rightside' );

// Custom search layout for video
function viewtube_custom_search_template($template) {    
  global $wp_query;   
  $post_type = get_query_var('post_type');   
  if( $wp_query->is_search && $post_type == 'video' )   
  {
    return locate_template('search-video.php');
  }   
  return $template;   
}
add_filter('template_include', 'viewtube_custom_search_template');


// Get option list
function viewtube_get_option_list($taxonomy, $meta, $post_id) { 
	$current_term = get_the_terms( $post_id, $taxonomy )[0]->slug;

	$terms = get_terms( array(
	    'taxonomy' => $taxonomy,
	    'hide_empty' => false,
		'orderby'   => 'name',
	) );
	$hierarchy ='';
	$hierarchy = _get_term_hierarchy($taxonomy);

	foreach ($terms as $term) { 
		if($term->parent) {
			continue;
		} ?>						
		<option <?php if ($term->slug == $current_term ){echo'selected ="selected"';} ?> value="<?php echo esc_attr( $term->term_id ); ?>"><?php echo esc_html( $term->name ); ?></option>

			<?php if (isset($hierarchy[$term->term_id])) {
				foreach ($hierarchy[$term->term_id] as $child){
					$child = get_term($child, $taxonomy); ?>

					<option <?php if ($child->slug == $current_term ){echo'selected ="selected"';} ?> value="<?php echo esc_attr( $child->term_id ); ?>">- <?php echo esc_html( $child->name ); ?></option>

					<?php if (isset($hierarchy[$child->term_id])) {
						foreach ($hierarchy[$child->term_id] as $child2){
							$child2 = get_term($child2, $taxonomy); ?>

							<option <?php if ($child2->slug == $current_term ){echo'selected ="selected"';} ?> value="<?php echo esc_attr( $child2->term_id ); ?>">-- <?php echo esc_html( $child2->name ); ?></option>

								<?php if (isset($hierarchy[$child2->term_id])) {
									foreach ($hierarchy[$child2->term_id] as $child3){
										$child3 = get_term($child3, $taxonomy); ?>

										<option <?php if ($child3->slug == $current_term ){echo'selected ="selected"';} ?> value="<?php echo esc_attr( $child3->term_id ); ?>">--- <?php echo esc_html( $child3->name ); ?></option>
									<?php }
								} ?>
						<?php }
					} ?>
				<?php }
			} ?>
	<?php }
}

// Get User IP
function viewtube_get_the_user_ip() {
	if ( ! empty( $_SERVER['HTTP_CLIENT_IP'] ) ) {
		//check ip from share internet
		$ip = $_SERVER['HTTP_CLIENT_IP'];
	} elseif ( ! empty( $_SERVER['HTTP_X_FORWARDED_FOR'] ) ) {
		//to check ip is pass from proxy
		$ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
	} else {
		$ip = $_SERVER['REMOTE_ADDR'];
	}
	return apply_filters( 'wpb_get_ip', $ip );
}

// Subscribe
require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
global $wpdb;
maybe_create_table( "viewtube_subscribe", "
	CREATE TABLE viewtube_subscribe (
		`id` int (11) NOT NULL AUTO_INCREMENT,
		`timestamp` datetime ,
		`updated_on` datetime,
		`subscriber_id` int (11),
		`content_creator_id` int (11),
		 PRIMARY KEY (id)
	) ENGINE=InnoDB DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;"
);