<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package viewtube
 */

global $viewtube_opt;

$site_preloader = !empty( $viewtube_opt['site_preloader'] ) ? $viewtube_opt['site_preloader'] : '';
$mood_switcher = !empty( $viewtube_opt['mood_switcher'] ) ? $viewtube_opt['mood_switcher'] : '';
$header_upload_button = !empty( $viewtube_opt['header_upload_button'] ) ? $viewtube_opt['header_upload_button'] : '';
$blog_breadcrumb_title = !empty($viewtube_opt['blog_breadcrumb_title']) ? $viewtube_opt['blog_breadcrumb_title'] : esc_html__( 'Latest news', 'viewtube' );
$dark_mood_logo = !empty($viewtube_opt['dark_mood_logo']['url']) ? $viewtube_opt['dark_mood_logo']['url'] : '';

?>

<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="https://gmpg.org/xfn/11">
	
	<?php wp_head(); ?>
	
</head>

<body <?php body_class(); ?>>
	 <?php wp_body_open(); ?>
	
	<?php if ($site_preloader): ?>
		<!-- Preloading -->
	    <div id="preloader">
	        <div class="spinner">
	        	<div class="uil-ripple-css"><div></div><div></div></div>
	        </div>
	    </div>
	<?php endif ?>
	
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'viewtube' ); ?></a>

    <header class="site-header fixed-top">
        <div class="container-fluid">
            <div class="row justify-content-between">
                <div class="col-xl-2 col-lg-2 my-auto d-none d-lg-block">
                	<div class="d-flex">
                		<?php if ( function_exists('viewtube_font_awesome_icon_custom_field') ) { ?>
                			<a href="#" class="sidebar-toggle">
				        		<i class="far fa-bars"></i>
				        	</a>
						<?php } ?>
	                    <div class="logo my-auto">
	                    <?php if (has_custom_logo()) {
	                    	if ($_COOKIE["layout_mood"] == 'dark') { ?>
                    			<a class="custom-logo-link" rel="home" href="<?php echo esc_url( home_url( '/' ) ); ?>">
	                    			<img src="<?php echo esc_url($dark_mood_logo); ?>" alt="<?php bloginfo( 'name' ); ?>">
	                    		</a>
		                    <?php
		                    } else {
	                        	the_custom_logo();
		                    }
	                    	
	                    } else { ?>
	                        <a class="navbar-logo-text" rel="home" href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>"><?php bloginfo( 'name' ); ?></a>
	                    <?php } ?>
	                    </div>
                	</div>
                </div>
                
        		<div class="col-xl-7 col-lg-7 my-auto d-none d-xl-block">
                    <form class="ajax-search-form" action="<?php echo esc_url(home_url( '/' )); ?>">
                        <input type="text" name="s" class="keyword" placeholder="<?php echo esc_attr_x( 'Search', 'placeholder', 'viewtube' ); ?>">
                        <button type="submit"><i class="fa fa-search"></i></button>
                        <input type="hidden" name="post_type" value="video" />
                    </form>
                    <div class="datafetch"></div>
                </div>

                <div class="col-xl-1 col-lg-1 my-auto text-right">
                	<?php if ($header_upload_button == true){ ?>
                		<a class="upload-video" href="<?php echo esc_url( home_url( '/upload-video' ) ); ?>"><i class="far fa-video-plus"></i></a>                		
                	<?php } ?>
                </div>
                <div class="col-xl-2 col-lg-2 my-auto">
                	<div class="d-flex">
	                	<div class="d-flex my-auto">      
                			<?php if ($mood_switcher == true){?>          		
		                		<?php if($_COOKIE["layout_mood"] == 'dark'){ ?>
			                		<i class="fad fa-moon my-auto"></i>
			                	<?php } else { ?>
		                			<i class="fad fa-sun my-auto"></i>
		                		<?php }?>
			                	<label class="toggle-switch">
								  	<input type="checkbox">
								  	<span class="slider round"></span>
								</label>           			
                			<?php } ?>
						</div>     
	                	<div class="d-flex float-right">
		                    <div class="top-header-action">
		                        <div class="widget-header">
		                            <div class="my-account-widget">
		                            	<div class="my-account-button">
		                                	<?php if ( is_user_logged_in() ) { 
	                                            $current_user = wp_get_current_user();
	                                            if ( ($current_user) ) { 
	                                                echo get_avatar( $current_user->ID, 45, '', 'Avatar' ,array(
	                                                	'class' => 'rounded-circle',
	                                                )); 
	                                            }
	                                        } else { ?>
	                                            <i class="fad fa-user"></i>
	                                        <?php } ?>
		                            	</div>
		                                <div class="my-account-content">
		                                    <?php if (is_user_logged_in()) { ?>

		                                        <div class="header-profile">                                        
		                                            <?php if ( is_user_logged_in() ) { 
		                                                $current_user = wp_get_current_user();
		                                                if ( ($current_user) ) { 
		                                                    echo get_avatar( $current_user->ID, 60 ); 
		                                                }
		                                            } else { ?>
		                                                <img src="<?php echo get_template_directory_uri() ?>/assets/images/user.png" alt="<?php the_title_attribute() ?>">
		                                            <?php } ?>
		                                            <div class="header-profile-content">
		                                                <h6><?php echo wp_get_current_user()->display_name; ?></h6>
		                                                <p><?php echo wp_get_current_user()->user_email ?></p>
		                                            </div>
		                                        </div>
		                                        <ul class="list-unstyled">
                                                	<li><a href="<?php echo esc_url( wp_logout_url() ); ?>"><?php echo esc_html__( 'Logout','viewtube' ) ?></a></li>
                                                </ul>
		                                    <?php } else { ?>

		                                        <div class="header-profile-login">
		                                            <h6 class="text-center"><?php echo esc_html__( 'Log In to Your Account', 'viewtube' ) ?></h6>
		                                            <?php wp_login_form(); ?>
		                                        </div>

		                                    <?php } ?>
		                                </div>
		                            </div>
		                        </div>
		                    </div>
	                    </div>
					</div>
                </div>
            </div>
        </div>
	</header><!-- #masthead -->

	<!--Mobile Navigation Toggler-->
	<div class="off-canvas-menu-bar">
	    <div class="pl-30 pr-30">
	        <div class="row">
	            <div class="col-7 my-auto">
	            <?php if (has_custom_logo()) {
            		if($_COOKIE["layout_mood"] == 'dark'){ ?>
            			<a class="custom-logo-link" rel="home" href="<?php echo esc_url( home_url( '/' ) ); ?>">
                			<img src="<?php echo esc_url($dark_mood_logo); ?>" alt="<?php bloginfo( 'name' ); ?>">
                		</a>
                	<?php } else {
                    	the_custom_logo();
                    }
	            } else { ?>
	                <a class="navbar-logo-text" rel="home" href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>"><?php bloginfo( 'name' ); ?></a>
	            <?php } ?>
	            </div>
	            <div class="col-3 my-auto">
	            	<?php if ($mood_switcher == true){?>
	                	<label class="toggle-switch">
						  	<input type="checkbox">
						  	<span class="slider round"></span>
						</label>           			
        			<?php } ?>
	            </div>
	            <div class="col-2 my-auto">
	                <div class="mobile-nav-toggler"><span class="fas fa-bars"></span></div>
	            </div>
	        </div>
	    </div>
	</div>

	<!-- Mobile Menu  -->
	<div class="off-canvas-menu">
	    <div class="menu-backdrop"></div>
	    <i class="close-btn fa fa-close"></i>
	    <nav class="mobile-nav">
	        <div class="text-center pt-3 pb-3">
	        <?php if (has_custom_logo()) {
            	if($_COOKIE["layout_mood"] == 'dark'){ ?>
        			<a class="custom-logo-link" rel="home" href="<?php echo esc_url( home_url( '/' ) ); ?>">
            			<img src="<?php echo esc_url($dark_mood_logo); ?>" alt="<?php bloginfo( 'name' ); ?>">
            		</a>
	        	<?php } else {
	        		the_custom_logo();
                }
	        } else { ?>
	            <a class="navbar-logo-text" rel="home" href="<?php echo esc_url( home_url( '/' ) ); ?>" title="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>"><?php bloginfo( 'name' ); ?></a>
	        <?php } ?>
	        </div>
	        
	        <ul class="navigation"><!--Keep This Empty / Menu will come through Javascript--></ul>
	    </nav>
	</div>
	
	<div class="container-fluid p-0">
		<div class="d-flex topspace-90">
			<div class="sidebar-menu open">
		        <nav class="desktop-menu">
		            <?php
		                wp_nav_menu( array(
		                'theme_location'    => 'primary',
		                'depth'             => 1,
		                'container'         => 'ul'
		            ) ); ?>
		        </nav>
			</div>
			<div class="main-container">
				<?php if ('video' !== get_post_type()): ?>
					<?php if ( !is_page_template( 'custom-page-without-breadcrumb.php' ) and !is_page_template( 'upload-video.php' ) ) { ?>
					<section class="breadcrumbs">
						<div class="container">
							<h1>
						    	<?php
						      	if(is_home() && is_front_page()){
						            echo esc_html( $blog_breadcrumb_title ); 
						      	} else { 
						            echo wp_title('', false);
						      	} ?>
						    </h1>
							<?php viewtube_breadcrumb(); ?>
						</div>
					</section>
					<?php } ?>
				<?php endif ?>