<?php

// Search
function viewtube_ajax_search(){
    $the_query = new WP_Query( array( 'posts_per_page' => 10 , 's' => esc_attr( $_POST['keyword'] ), 'post_type' => 'video' ) );
      if( $the_query->have_posts() ) { ?>
      <ul class="ajax-search-results list-unstyled">
        <?php
        while( $the_query->have_posts() ){ $the_query->the_post(); ?>
        <li>
          <a href="<?php echo esc_url( get_permalink() ); ?>">
            <?php
              the_post_thumbnail( 'viewtube-32x32');
              the_title();
            ?>
          </a>
        </li>
        <?php }; ?>
      </ul>
      <?php
      wp_reset_postdata();  
      }
  die();
}

add_action( 'wp_ajax_viewtube_ajax_search',  'viewtube_ajax_search' );
add_action( 'wp_ajax_nopriv_viewtube_ajax_search',  'viewtube_ajax_search' );


// Upload file
function viewtube_ajax_upload_file(){
  if ( ! wp_verify_nonce( $_REQUEST['nonce'], 'upload_file_nonce' ) || ! isset( $_REQUEST['nonce'] ) ) {
      exit( "No naughty business please" );
  }

  require_once( ABSPATH . 'wp-admin/includes/image.php' );
  require_once( ABSPATH . 'wp-admin/includes/file.php' );
  require_once( ABSPATH . 'wp-admin/includes/media.php' );

  $attachment_id = media_handle_upload( 'file', $_POST['video_id']);

  //Check for errors
  if ( is_wp_error( $attachment_id ) ) {
      echo 'Error';
  } else {
      echo json_encode(
        array(
          'id' => $attachment_id,
          'type' => get_post_mime_type( $attachment_id ),
          'image' => wp_get_attachment_image( $attachment_id, 'full'),
          'video' => wp_get_attachment_url( $attachment_id )
        )
      );
  }

  wp_die();
}

add_action( 'wp_ajax_viewtube_ajax_upload_file',  'viewtube_ajax_upload_file' );
add_action( 'wp_ajax_nopriv_viewtube_ajax_upload_file',  'viewtube_ajax_upload_file' );


// Submit Video
function viewtube_ajax_submit_video(){
  if ( ! wp_verify_nonce( $_REQUEST['nonce'], 'submit_video_nonce' ) || ! isset( $_REQUEST['nonce'] ) ) {
      exit( "No naughty business please" );
  }

  $video_id = $_POST['video_id'];
  $params = array();
  parse_str($_POST['video_data'], $params);
  
  $result = wp_update_post(array(
    'ID' => $video_id,
    'post_title' => sanitize_text_field($params['title']),
    'post_content' => wp_kses_post($params['description']),
    'post_type' => 'video',
    'post_author' => get_current_user_id(),
    'post_status'   => 'pending'
  ), true);

  if (is_wp_error($result)) {
    wp_send_json_error(array('message' => esc_html__( 'Error!!! Please contact admin', 'viewtube' )));
  }

  if(isset($params['_thumbnail-id'])) {
    set_post_thumbnail( $video_id, $params['_thumbnail-id'] );
  }

  if(isset($params['category'])) {
    $type_terms = array((int)$params['category']);
    wp_set_post_terms( $video_id, $type_terms, 'video_category', false );
  }

  if ($params['video-display-as'] == 'default') {
    
    if(isset($params['url'])) {
      update_post_meta( $video_id, 'video_file', $params['url']);
    }

    if(isset($params['_video-id'])){
      update_post_meta( $video_id, 'video_file', wp_get_attachment_url( $params['_video-id'] ));
    }

    if(isset($params['video-caption-url'])) {
      update_post_meta( $video_id, 'video_caption_file', $params['video-caption-url']);
    }

  } elseif ($params['video-display-as'] == 'youtube') {
    if(isset($params['youtube'])) {
      update_post_meta( $video_id, 'youtube_video_url', $params['youtube']);
    }
  } elseif ($params['video-display-as'] == 'vimeo') {
    if(isset($params['vimeo'])) {
      update_post_meta( $video_id, 'vimeo_video_url', $params['vimeo']);
    }
  }  

  if(isset($params['video-duration'])) {
    update_post_meta( $video_id, 'video_duration', $params['video-duration']);
  }

  if(isset($params['video-resolution'])) {
    update_post_meta( $video_id, 'video_resolution', $params['video-resolution']);
  }


  if(isset($params['video-display-as'])) {
    update_post_meta( $video_id, 'video_display_as', $params['video-display-as']);
  }

  update_post_meta( $video_id, 'video_release', get_the_time( "M d Y", $video_id ));

  wp_die();
}

add_action( 'wp_ajax_viewtube_ajax_submit_video',  'viewtube_ajax_submit_video' );
add_action( 'wp_ajax_nopriv_viewtube_ajax_submit_video',  'viewtube_ajax_submit_video' );


// Like Button
function viewtube_ajax_like_button(){ 
  if ( ! wp_verify_nonce( $_REQUEST['nonce'], 'viewtube_like_nonce' ) || ! isset( $_REQUEST['nonce'] ) ) {
      exit( "No naughty business please" );
  }

  global $wpdb; 

  $likes = get_post_meta( $_POST['post_id'], 'like_'.viewtube_get_the_user_ip(), true );
  $dislikes = get_post_meta( $_POST['post_id'], 'dislike_'.viewtube_get_the_user_ip(), true );

  $current_post_id = $_POST['post_id'];
  $like_count = $wpdb->get_results( "SELECT meta_value FROM $wpdb->postmeta WHERE post_id = '$current_post_id' AND meta_key LIKE 'like_%'" );
  $dislike_count = $wpdb->get_results( "SELECT meta_value FROM $wpdb->postmeta WHERE post_id = '$current_post_id' AND meta_key LIKE 'dislike_%'" );

  // First remove dislike if exist
  if (!empty($dislikes)) {
      delete_post_meta( $_POST['post_id'], 'dislike_'.viewtube_get_the_user_ip());
  }

  // Add like if not exist
  if (!empty($likes)) {
    delete_post_meta( $_POST['post_id'], 'like_'.viewtube_get_the_user_ip());
    wp_send_json_error(array(
      'message' => esc_html__( 'Like Removed!', 'viewtube' ),
      'count' => count($like_count)
    ));
  }

  update_post_meta( $_POST['post_id'], 'like_'.viewtube_get_the_user_ip(), $_POST['post_id'] );
  wp_send_json_success(array(
    'message' => esc_html__( 'You like added!', 'viewtube' ),
    'count' => count($like_count),
    'discount' => count($dislike_count)
  ));

  die();
}

add_action( 'wp_ajax_viewtube_ajax_like_button',  'viewtube_ajax_like_button' );
add_action( 'wp_ajax_nopriv_viewtube_ajax_like_button',  'viewtube_ajax_like_button' );

// Dislike Button
function viewtube_ajax_dislike_button(){ 
  if ( ! wp_verify_nonce( $_REQUEST['nonce'], 'viewtube_dislike_nonce' ) || ! isset( $_REQUEST['nonce'] ) ) {
      exit( "No naughty business please" );
  }
  global $wpdb; 

  $dislikes = get_post_meta( $_POST['post_id'], 'dislike_'.viewtube_get_the_user_ip(), true );
  $likes = get_post_meta( $_POST['post_id'], 'like_'.viewtube_get_the_user_ip(), true );

  $current_post_id = $_POST['post_id'];
  $like_count = $wpdb->get_results( "SELECT meta_value FROM $wpdb->postmeta WHERE post_id = '$current_post_id' AND meta_key LIKE 'like_%'" );
  $dislike_count = $wpdb->get_results( "SELECT meta_value FROM $wpdb->postmeta WHERE post_id = '$current_post_id' AND meta_key LIKE 'dislike_%'" );

  // First remove like if exist
  if (!empty($likes)) {    
    delete_post_meta( $_POST['post_id'], 'like_'.viewtube_get_the_user_ip());
  }

  // Remove Dislike if already exist
  if (!empty($dislikes)) {
    delete_post_meta( $_POST['post_id'], 'dislike_'.viewtube_get_the_user_ip());
    wp_send_json_error(array(
      'message' => esc_html__( 'Dislike Removed!', 'viewtube' ),
      'count' => count($dislike_count)
    ));
  }

  // Add dislike
  update_post_meta( $_POST['post_id'], 'dislike_'.viewtube_get_the_user_ip(), $_POST['post_id'] );
  wp_send_json_success(array(
    'message' => esc_html__( 'You dislike added!', 'viewtube' ),
    'count' => count($dislike_count),
    'discount' => count($like_count)
  ));

  die();
}

add_action( 'wp_ajax_viewtube_ajax_dislike_button',  'viewtube_ajax_dislike_button' );
add_action( 'wp_ajax_nopriv_viewtube_ajax_dislike_button',  'viewtube_ajax_dislike_button' );

// Subscribe
function viewtube_ajax_subscribe(){

    if ( ! wp_verify_nonce( $_REQUEST['nonce'], 'viewtube_subscribe_nonce' ) || ! isset( $_REQUEST['nonce'] ) ) {
        exit( "No naughty business please" );
    }
    
    global $wpdb;  

    $subscriber_id = $_POST['subscriber_id'];
    $content_creator_id = $_POST['content_creator_id'];
    $table ='viewtube_subscribe';

    if($wpdb->get_var("SHOW TABLES LIKE '$table'") == $table) {
      $query = "SELECT * FROM ".$table." WHERE `subscriber_id` = '".$subscriber_id."' AND `content_creator_id` = '" . $content_creator_id . "'";
      $check_subscription = $wpdb->get_results($query, ARRAY_A)[0];
    } 

    if ($subscriber_id !== '0') {
      if(empty($check_subscription)) {

        $wpdb->insert('viewtube_subscribe',array(
          'timestamp' => current_time('mysql'),
          'updated_on' => current_time('mysql'),
          'subscriber_id' => sanitize_text_field($subscriber_id),
          'content_creator_id' => sanitize_text_field($content_creator_id)
        ));

        wp_send_json_success(array('message' => esc_html__( 'Subscribe!', 'viewtube' )));
      } else {
        $wpdb->delete('viewtube_subscribe',array(
          'id' => $check_subscription['id']
        ));
        wp_send_json_error(array('message' => esc_html__( 'Unsubscribed!', 'viewtube' )));  
      }
    } else {
      wp_send_json_error(array('message' => esc_html__( 'Please login!', 'viewtube' )));  
    }
}

add_action( 'wp_ajax_viewtube_ajax_subscribe',  'viewtube_ajax_subscribe' );
add_action( 'wp_ajax_nopriv_viewtube_ajax_subscribe',  'viewtube_ajax_subscribe' );
