<?php 
add_action( 'cmb2_admin_init', 'cmb2_sample_metaboxes' );
/**
 * Define the metabox and field configurations.
 */
function cmb2_sample_metaboxes() {

	/**
	 * Initiate the metabox
	 */
	$video = new_cmb2_box( array(
		'id'            => 'video_metabox',
		'title'         => __( 'Video Metabox', 'viewtube' ),
		'object_types'  => array( 'video' ),
		'context'       => 'normal',
		'priority'      => 'high',
		'show_names'    => true,
	) );

	// Video Upload
	$video->add_field( array(
		'name'    => 'Video File',
		'desc'    => 'Upload a video or enter an URL.',
		'id'      => 'video_file',
		'type'    => 'file',
		'options' => array(
			'url' => true,
		),
		'text'    => array(
			'add_upload_file_text' => 'Add Video'
		),

		'query_args' => array(
			'type' => array(
				'video/mp4',
				'video/mpeg',
				'video/H264'
			),
		),
		'preview_size' => 'large',
	) );

	// Caption Upload
	$video->add_field( array(
		'name'    => 'Caption',
		'desc'    => 'Upload a caption or enter an URL.',
		'id'      => 'video_caption_file',
		'type'    => 'file',
		'options' => array(
			'url' => true,
		),
		'text'    => array(
			'add_upload_file_text' => 'Add Caption File'
		)
	) );

	// YouTube Video URL
	$video->add_field( array(
		'name' => __( 'YouTube Video URL', 'viewtube' ),
		'id'   => 'youtube_video_url',
		'type' => 'oembed',
	) );

	// Vimeo Video URL
	$video->add_field( array(
		'name' => __( 'Vimeo Video URL', 'viewtube' ),
		'desc' => __( 'example: https://player.vimeo.com/video/76979871', 'viewtube' ),
		'id'   => 'vimeo_video_url',
		'type' => 'oembed',
	) );

	// Duration
	$video->add_field( array(
		'name' => __( 'Duration', 'viewtube' ),
		'id'   => 'video_duration',
		'type' => 'text',
	) );

	// Release
	$video->add_field( array(
		'name' => __( 'Release Date', 'viewtube' ),
		'id'   => 'video_release',
		'type' => 'text_date',
		'date_format' => 'M d Y',
	) );

	// Video video resolution
	$video->add_field( array(
		'name'           => 'Video resolution',
		'id'             => 'video_resolution',
		'type'           => 'radio',
		'show_option_none' => true,
		'options'  => array(
			'HD' => __( 'HD', 'viewtube' ),
			'4K' => __( '4K', 'viewtube' ),
			'8K' => __( '8K', 'viewtube' )
		),
		'default' => 'hd',
	) );

	// Video Display As
	$video->add_field( array(
		'name'           => 'Video Display As',
		'id'             => 'video_display_as',
		'type'           => 'radio',
		'options'  => array(
			'default' => __( 'Default', 'viewtube' ),
			'youtube' => __( 'YouTube', 'viewtube' ),
			'vimeo'   => __( 'Vimeo', 'viewtube' ),
		),
		'default' => 'default',
	) );

}