<?php

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }

    $opt_name = "viewtube_opt";
    $theme = wp_get_theme();

    $args = array(
        'opt_name'             => $opt_name,
        'display_name'         => $theme->get( 'Name' ),
        'display_version'      => $theme->get( 'Version' ),
        'menu_type'            => 'menu',
        'allow_sub_menu'       => true,
        'menu_title'           => esc_html__( 'ViewTube', 'viewtube' ),
        'page_title'           => esc_html__( 'ViewTube', 'viewtube' ),
        'google_api_key'       => '',
        'google_update_weekly' => false,
        'async_typography'     => false,
        'admin_bar'            => true,
        'admin_bar_icon'       => 'dashicons-portfolio',
        'admin_bar_priority'   => 50,
        'global_variable'      => '',
        'dev_mode'             => false,
        'update_notice'        => true,
        'customizer'           => true,
        'page_priority'        => null,
        'page_parent'          => 'themes.php',
        'page_permissions'     => 'manage_options',
        'menu_icon'            => '',
        'last_tab'             => '',
        'page_icon'            => 'icon-themes',
        'page_slug'            => '_options',
        'save_defaults'        => true,
        'default_show'         => false,
        'default_mark'         => '',
        'show_import_export'   => true,
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        'output_tag'           => true,
        'database'             => '',
        'use_cdn'              => true,

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'light',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );

    Redux::setArgs( $opt_name, $args );


    // General
    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'General', 'viewtube' ),
        'id'     => 'general',
        'desc'   => esc_html__( 'General theme options.', 'viewtube' ),
        'icon'   => 'el el-home',
        'fields' => array(
            array(
                'id'       => 'site_preloader',
                'type'     => 'switch',
                'title'    => esc_html__( 'Preloader', 'viewtube' ),
                'default'  => true,
            )
        )
    ));

    // Style
    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Style', 'viewtube' ),
        'id'     => 'style',
        'icon'   => 'el el-edit',
        'fields' => array(
            array(
                'id'       => 'dark_mood',
                'type'     => 'switch',
                'title'    => esc_html__('Dark Mood', 'viewtube'),
                'default'  => true,
            ), 
            array(
                'id'       => 'primary_color',
                'type'     => 'color_gradient',
                'title'    => esc_html__('Primary Color', 'viewtube'), 
                'subtitle' => esc_html__('Pick a color for the theme (default: #ff0000 and #d60000).', 'viewtube'),
                'validate' => 'color',
                'default'  => array(
                    'from' => '#e90101',
                    'to'   => '#e90101',
                ),
            ),  
        )
    ));

    // Typography
    Redux::setSection( $opt_name, array(
        'title'            => esc_html__( 'Typography', 'viewtube' ),
        'id'               => 'page_title_typography',  
        'icon'   => 'el el-pencil',
        'fields'           => array(
            array(
                'id'          => 'viewtube_heading_typography',
                'type'        => 'typography',
                'title'       => esc_html__( 'Heading Typography', 'viewtube' ),
                'subtitle'    => esc_html__('H1, H2, H3,H4, H5, H6  Tags', 'viewtube'),
                'google'      => true, 
                'font-backup' => true,
                'output'      => array('h1,h2,h3,h4,h5,h6'),
                'units'       =>'px',
                'default'     => array(
                    'color'       => '#333',
                    'font-family' => 'Fira Sans Condensed', 
                    'google'      => true,
                ),
            ),
            array(
                'id'          => 'viewtube_typography',
                'type'        => 'typography',
                'title'       => esc_html__( 'Typography', 'viewtube' ),
                'subtitle'    => esc_html__('body, p Tags', 'viewtube'),
                'google'      => true, 
                'font-backup' => true,
                'output'      => array('body,p'),
                'units'       =>'px',
                'default'     => array(
                    'color'       => '#444', 
                    'font-weight'  => 'normal', 
                    'line-height' => '26px',
                    'font-family' => 'Open Sans',
                    'google'      => true,
                    'font-size'   => '16px',
                ),
            )
        )
    ) );

    // Header

    // Templates
    $elementor_library = new WP_Query( array( 
        'post_type' => 'elementor_library'
    ));

    $template_lists = [];

    /* Start the Loop */
    if ( $elementor_library->have_posts()) {
        while ( $elementor_library->have_posts()) : $elementor_library->the_post();
            $template_lists[ get_the_ID() ] = get_the_title();
        endwhile;
    }

    // Header
    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Header', 'viewtube' ),
        'id'     => 'header',
        'desc'   => esc_html__( 'Header menu options.', 'viewtube' ),
        'icon'   => 'el el-heart-empty',
        'fields' => array(  
            array(
                'id'          => 'dark_mood_logo',
                'type'        => 'media',
                'title'       => esc_html__( 'Dark Mood Logo', 'viewtube' ),
            ),
            array(
                'id'       => 'mood_switcher',
                'type'     => 'switch',
                'title'    => esc_html__('Mood switcher', 'viewtube'),
                'default'  => true,
            ),  
            array(
                'id'       => 'header_upload_button',
                'type'     => 'switch',
                'title'    => esc_html__('Upload Button', 'viewtube'),
                'default'  => true,
            ),
            array(         
                'id'       => 'breadcrumbs',
                'type'     => 'background',
                'output'     => array('.breadcrumbs'),
                'title'    => esc_html__('Breadcrumbs', 'viewtube'),
                'subtitle' => esc_html__('Set breadcrumbs background with image, color', 'viewtube'),
                'default'  => array(
                    'background-color' => '#181818',
                )
            )
        )
    ) );

    // Blog Page
    Redux::setSection( $opt_name, array(
        'title' => esc_html__( 'Blog Page', 'viewtube' ),
        'id'    => 'blog_page',
        'icon'  => 'el el-wordpress',
        'fields'     => array(         
            array(
                'id'       => 'blog_breadcrumb_title',
                'type'     => 'text',
                'title'    => esc_html__( 'Breadcrumb Title', 'viewtube' ),
                'default'  => esc_html__( 'Latest Blog', 'viewtube' ),
            ),   
            array(
                'id'               => 'viewtube_excerpt_length',
                'type'             => 'slider',
                'title'            => esc_html__('Excerpt Length', 'viewtube'),
                'subtitle'         => esc_html__('Controls the excerpt length on blog page','viewtube'),
                "default"          => 55,
                "min"              => 10,
                "step"             => 2,
                "max"              => 130,
                'display_value'    => 'text'
            )
            
        )
    ) );

    // Single Blog
    Redux::setSection( $opt_name, array(
        'title' => esc_html__( 'Single Blog Page', 'viewtube' ),
        'id'    => 'single_blog_page',
        'icon'  => 'el el-wordpress',
        'subsection' => true,
        'fields'     => array(              
            array(
                'id'       => 'social_share',
                'type'     => 'switch',
                'title'    => esc_html__( 'Social Share', 'viewtube' ),
                'default'  => true,
            ),
            array(
                'id'       => 'viewtube_blog_details_post_navigation',
                'type'     => 'switch',
                'title'    => esc_html__( 'Post Navigation (Next/Previous)', 'viewtube' ),
                'default'  => true,
            ),
            array(
                'id'       => 'related_posts',
                'type'     => 'switch',
                'title'    => esc_html__( 'Show Related Post', 'viewtube' ),
                'default'  => true,
            ),
            array(
                'id'       => 'related_post_title',
                'type'     => 'text',
                'title'    => esc_html__( 'Related Post Title', 'viewtube' ),
                'required' => array( 'related_posts','equals', true ),
                'default'  => esc_html__( 'Related Post', 'viewtube' ),
            ),
            array(
                'id' => 'posts_per_page',
                'type' => 'slider',
                'title' => esc_html__( 'Related Posts', 'viewtube' ),
                'subtitle' => esc_html__( 'Related posts per page', 'viewtube' ),
                'desc' => esc_html__('Number of related posts to display. Min: 1, max: Unlimited, step: 1, default value: 4', 'viewtube'),
                "default" => 2,
                "min" => 1,
                "step" => 1,
                "max" => 10000,
                'required' => array( 'related_posts','equals', true ),
                'display_value' => 'text'
            ),
            array(
                'id'       => 'related_posts_columns',
                'type'     => 'select',
                'title'    => esc_html__( 'Posts Column', 'viewtube' ), 
                'subtitle' => esc_html__( 'Number of column', 'viewtube' ),
                'desc'     => esc_html__( 'Specify the number of related posts column.', 'viewtube' ),
                'required' => array( 'related_posts','equals', true ),
                'options'  => array(
                    '12' => esc_html__( 'One Column','viewtube' ), 
                     '6' => esc_html__( 'Two Columns','viewtube' ), 
                     '4' => esc_html__( 'Three Columns','viewtube' ), 
                     '3' => esc_html__( 'Four Columns','viewtube' ), 
                     '2' => esc_html__( 'Six Columns','viewtube' ),
                ),
                'default'  => '6',
            )
        )
    ) );


    // Video
    Redux::setSection( $opt_name, array(
        'title' => esc_html__( 'Video', 'viewtube' ),
        'id'    => 'video',
        'icon'  => 'el el-video',
        'fields'     => array(
            array(
                'id'       => 'video_preview_mode',
                'type'     => 'select',
                'title'    => esc_html__( 'Video Preview Mode', 'viewtube' ), 
                'desc'     => esc_html__( 'Specify the mode of preview video card. to increase loading speed we prefer use "thumbnail"', 'viewtube' ),
                'options'  => array(
                    'thumbnail' => esc_html__( 'Thumbnail','viewtube' ), 
                    'video' => esc_html__( 'Video','viewtube' )
                ),
                'default'  => 'thumbnail',
            ),
        )
    ));


    // Single Video
    Redux::setSection( $opt_name, array(
        'title' => esc_html__( 'Single Video Page', 'viewtube' ),
        'id'    => 'single_video_page',
        'icon'  => 'el el-video',
        'subsection' => true,
        'fields'     => array(              
            array(
                'id'       => 'video_social_share',
                'type'     => 'switch',
                'title'    => esc_html__( 'Social Share', 'viewtube' ),
                'default'  => true,
            ),
            array(
                'id'       => 'viewtube_video_details_post_navigation',
                'type'     => 'switch',
                'title'    => esc_html__( 'Post Navigation (Next/Previous)', 'viewtube' ),
                'default'  => true,
            )
        )
    ) );

    // Newsletter Modal
    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Newsletter Modal', 'viewtube' ),
        'id'     => 'newsletter_modal',
        'icon'   => 'el el-envelope',
        'fields' => array(
            array(
                'id'          => 'newsletter_modal_switch',
                'type'        => 'switch',
                'title'       => esc_html__( 'Newsletter Modal', 'viewtube' ),
                'default'  => true,
            ),
            array(
                'id'          => 'modal_image',
                'type'        => 'media',
                'title'       => esc_html__( 'Modal image', 'viewtube' ),
                'default'  => '#',
                'required' => array( 'newsletter_modal_switch','equals', true ),
            ),
            array(
                'id'          => 'modal_title',
                'type'        => 'text',
                'title'       => esc_html__( 'Modal title', 'viewtube' ),
                'default'     => esc_html__( 'Subscribe And Get 30% Discount!', 'viewtube' ),
                'required'    => array( 'newsletter_modal_switch','equals', true ),
            ),
            array(
                'id'          => 'modal_description',
                'type'        => 'textarea',
                'title'       => esc_html__( 'Modal description', 'viewtube' ),
                'default'     => esc_html__( 'Subscribe to our newsletter to get updates and big discount offer!.', 'viewtube' ),
                'required'    => array( 'newsletter_modal_switch','equals', true ),
            ),
            array(
                'id'          => 'modal_shortcode',
                'type'        => 'text',
                'title'       => esc_html__( 'Modal shortcode', 'viewtube' ),
                'default'  => '[mc4wp_form id="302"]',
                'required' => array( 'newsletter_modal_switch','equals', true ),
            ),
            array(
                'id'          => 'modal_timeout',
                'type'        => 'text',
                'title'       => esc_html__( 'Modal timeout', 'viewtube' ),
                'default'  => 5000,
                'required' => array( 'newsletter_modal_switch','equals', true ),
            )
        )
    ) );


    // Footer
    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( 'Footer', 'viewtube' ),
        'id'     => 'footer',
        'icon'   => 'el el-arrow-down',
        'fields' => array(
            array(
                'id'          => 'footer_widget_display',
                'type'        => 'switch',
                'title'       => esc_html__( 'Footer widget display', 'viewtube' ),
                'default'  => true,
            ),
            array(
                'id'         => 'viewtube_footer_template',
                'type'       => 'select',
                'title'      => esc_html__( 'Footer template', 'viewtube' ), 
                'required'   => array( 'footer_widget_display','equals', true ),
                'desc'       => esc_html__('To set a footer template click ', 'viewtube').' <a href="edit.php?post_type=elementor_library&tabs_group=library&elementor_library_type=page">'.esc_html__('Here', 'viewtube').'</a>',
                'options'  => $template_lists
            ),
            array(
                'id'          => 'backtotop',
                'type'        => 'switch',
                'title'       => esc_html__( 'Back to top', 'viewtube' ),
                'default'  => true,
            ),
            array(
                'id'              => 'viewtube_copyright_info',
                'type'            => 'editor',
                'title'           => esc_html__( 'Copyright text', 'viewtube' ),
                'subtitle'        => esc_html__( 'Enter your company information here. HTML tags allowed: a, br, em, strong', 'viewtube' ),
                'default'         => esc_html__( 'Copyright © 2021 viewtube All Rights Reserved.', 'viewtube' ),
                'args'            => array(
                'wpautop'         => false,
                'teeny'           => true,
                'textarea_rows'   => 5
                )
            )
        )
    ) );

    // 404 
    Redux::setSection( $opt_name, array(
        'title'  => esc_html__( '404 Error', 'viewtube' ),
        'id'     => 'error-page',
        'icon'   => 'el el-error-alt',
        'fields' => array(
            array(
                'id'          => 'viewtube_error_title',
                'type'        => 'text',
                'title'       => esc_html__( 'Error title', 'viewtube' ),
                'default'     => esc_html__( 'Oops! That page can’t be found.', 'viewtube' ),
                ),
            array(
                'id'          => 'viewtube_error_text',
                'type'        => 'textarea',
                'title'       => esc_html__('Error message', 'viewtube'),
                'subtitle'    => esc_html__('Enter "not found" error message.', 'viewtube'),
                'default'     => esc_html__('It looks like nothing was found at this location. Maybe try one of the links below or a search?', 'viewtube'),
                )
            ),
    ) );